@@ -5,6 +5,7 @@ import (
 	"strings"
 
 	"github.com/cloudskiff/driftctl/build"
+	"github.com/cloudskiff/driftctl/pkg"
 	"github.com/cloudskiff/driftctl/sentry"
 	"github.com/sirupsen/logrus"
 	"github.com/spf13/cobra"
@@ -65,7 +66,7 @@ func NewDriftctlCmd(build build.BuildInterface) *DriftctlCmd {
 	cmd.PersistentFlags().BoolP("disable-telemetry", "", false, "Disable telemetry")
 	cmd.PersistentFlags().BoolP("send-crash-report", "", false, "Enable error reporting. Crash data will be sent to us via Sentry.\nWARNING: may leak sensitive data (please read the documentation for more details)\nThis flag should be used only if an error occurs during execution")
 
-	cmd.AddCommand(NewScanCmd())
+	cmd.AddCommand(NewScanCmd(&pkg.ScanOptions{}))
 	cmd.AddCommand(NewGenDriftIgnoreCmd())
 
 	return cmd
