@@ -98,6 +98,9 @@ func (d DriftCTL) Run() (*analyser.Analysis, error) {
 		middlewares.NewAwsRouteTableExpander(d.alerter, d.resourceFactory),
 		middlewares.NewAwsDefaultRouteTable(),
 		middlewares.NewAwsDefaultRoute(),
+		middlewares.NewAwsDefaultNetworkACL(),
+		middlewares.NewAwsDefaultNetworkACLRule(),
+		middlewares.NewAwsNetworkACLExpander(d.resourceFactory),
 		middlewares.NewAwsNatGatewayEipAssoc(),
 		middlewares.NewAwsBucketPolicyExpander(d.resourceFactory),
 		middlewares.NewAwsSQSQueuePolicyExpander(d.resourceFactory, d.resourceSchemaRepository),
@@ -106,11 +109,24 @@ func (d DriftCTL) Run() (*analyser.Analysis, error) {
 		middlewares.NewAwsRoleManagedPolicyExpander(d.resourceFactory),
 		middlewares.NewTagsAllManager(),
 		middlewares.NewEipAssociationExpander(d.resourceFactory),
+		middlewares.NewRDSClusterInstanceExpander(d.resourceFactory),
+		middlewares.NewAwsApiGatewayDeploymentExpander(d.resourceFactory),
+		middlewares.NewAwsApiGatewayResourceExpander(d.resourceFactory),
+		middlewares.NewAwsApiGatewayRestApiExpander(d.resourceFactory),
+		middlewares.NewAwsApiGatewayRestApiPolicyExpander(d.resourceFactory),
+
+		middlewares.NewGoogleIAMBindingTransformer(d.resourceFactory),
+		middlewares.NewGoogleIAMPolicyTransformer(d.resourceFactory),
+
+		middlewares.NewAzurermRouteExpander(d.resourceFactory),
+		middlewares.NewAzurermSubnetExpander(d.resourceFactory),
 	)
 
 	if !d.opts.StrictMode {
 		middleware = append(middleware,
 			middlewares.NewAwsDefaults(),
+			middlewares.NewGoogleLegacyBucketIAMMember(),
+			middlewares.NewGoogleDefaultIAMMember(),
 		)
 	}
 
