@@ -21,48 +21,48 @@ func NewIamPolicyAttachmentTransformer(resourceFactory resource.ResourceFactory)
 	}
 }
 
-func (m IamPolicyAttachmentTransformer) Execute(remoteResources, resourcesFromState *[]resource.Resource) error {
+func (m IamPolicyAttachmentTransformer) Execute(remoteResources, resourcesFromState *[]*resource.Resource) error {
 	*remoteResources = m.transform(remoteResources)
 	*resourcesFromState = m.transform(resourcesFromState)
 	return nil
 }
 
-func (m IamPolicyAttachmentTransformer) transform(resources *[]resource.Resource) []resource.Resource {
-	var newResources []resource.Resource
+func (m IamPolicyAttachmentTransformer) transform(resources *[]*resource.Resource) []*resource.Resource {
+	var newResources []*resource.Resource
 	for _, res := range *resources {
-		if res.TerraformType() != aws.AwsIamUserPolicyAttachmentResourceType &&
-			res.TerraformType() != aws.AwsIamRolePolicyAttachmentResourceType {
+		if res.ResourceType() != aws.AwsIamUserPolicyAttachmentResourceType &&
+			res.ResourceType() != aws.AwsIamRolePolicyAttachmentResourceType {
 			newResources = append(newResources, res)
 			continue
 		}
 
-		if res.TerraformType() == aws.AwsIamUserPolicyAttachmentResourceType {
+		if res.ResourceType() == aws.AwsIamUserPolicyAttachmentResourceType {
 			attrs := *res.Attributes()
 			policyAttachmentData := resource.Attributes{
-				"id":         res.TerraformId(),
+				"id":         res.ResourceId(),
 				"policy_arn": attrs["policy_arn"],
 				"users":      []interface{}{attrs["user"]},
 				"groups":     []interface{}{},
 				"roles":      []interface{}{},
 			}
 
-			policyAttachment := m.resourceFactory.CreateAbstractResource(aws.AwsIamPolicyAttachmentResourceType, res.TerraformId(), policyAttachmentData)
+			policyAttachment := m.resourceFactory.CreateAbstractResource(aws.AwsIamPolicyAttachmentResourceType, res.ResourceId(), policyAttachmentData)
 
 			newResources = append(newResources, policyAttachment)
 			continue
 		}
 
-		if res.TerraformType() == aws.AwsIamRolePolicyAttachmentResourceType {
+		if res.ResourceType() == aws.AwsIamRolePolicyAttachmentResourceType {
 			attrs := *res.Attributes()
 			policyAttachmentData := resource.Attributes{
-				"id":         res.TerraformId(),
+				"id":         res.ResourceId(),
 				"policy_arn": attrs["policy_arn"],
 				"users":      []interface{}{},
 				"groups":     []interface{}{},
 				"roles":      []interface{}{attrs["role"]},
 			}
 
-			policyAttachment := m.resourceFactory.CreateAbstractResource(aws.AwsIamPolicyAttachmentResourceType, res.TerraformId(), policyAttachmentData)
+			policyAttachment := m.resourceFactory.CreateAbstractResource(aws.AwsIamPolicyAttachmentResourceType, res.ResourceId(), policyAttachmentData)
 
 			newResources = append(newResources, policyAttachment)
 			continue
