@@ -23,13 +23,13 @@ func (e *Route53HealthCheckEnumerator) SupportedType() resource.ResourceType {
 	return aws.AwsRoute53HealthCheckResourceType
 }
 
-func (e *Route53HealthCheckEnumerator) Enumerate() ([]resource.Resource, error) {
+func (e *Route53HealthCheckEnumerator) Enumerate() ([]*resource.Resource, error) {
 	healthChecks, err := e.repository.ListAllHealthChecks()
 	if err != nil {
 		return nil, remoteerror.NewResourceListingError(err, string(e.SupportedType()))
 	}
 
-	results := make([]resource.Resource, len(healthChecks))
+	results := make([]*resource.Resource, len(healthChecks))
 
 	for _, healthCheck := range healthChecks {
 		results = append(
