@@ -2,7 +2,9 @@ package cache
 
 import (
 	"fmt"
+	"sync"
 	"testing"
+	"time"
 
 	"github.com/cloudskiff/driftctl/pkg/resource"
 	"github.com/stretchr/testify/assert"
@@ -96,4 +98,60 @@ func TestCache(t *testing.T) {
 		}
 		assert.Equal(t, 0, cache.Len())
 	})
+
+	t.Run("cache will not panic for parallel calls", func(t *testing.T) {
+		key := "sameKeyForMultiplesRoutines"
+
+		cache := New(1)
+
+		wg := sync.WaitGroup{}
+		missCount := 0
+
+		for i := 0; i < 100; i++ {
+			wg.Add(1)
+			go func() {
+				defer wg.Done()
+				hit := cache.Get(key)
+				if hit != nil {
+					return
+				}
+				missCount++
+				time.Sleep(10 * time.Millisecond)
+				cache.Put(key, "value")
+			}()
+		}
+
+		wg.Wait()
+		assert.Equal(t, cache.Get(key), "value")
+		assert.Greater(t, missCount, 1)
+	})
+
+	t.Run("cache should be missed only once with parallel calls and GetAndLock usage", func(t *testing.T) {
+		key := "sameKeyForMultiplesRoutines"
+
+		cache := New(1)
+
+		nbRoutines := 100
+		wg := sync.WaitGroup{}
+		wg.Add(nbRoutines)
+
+		missCount := 0
+		for i := 0; i < nbRoutines; i++ {
+			go func() {
+				defer wg.Done()
+				hit := cache.GetAndLock(key)
+				defer cache.Unlock(key)
+				if hit != nil {
+					return
+				}
+				missCount++
+				time.Sleep(1 * time.Millisecond)
+				cache.Put(key, "value")
+			}()
+		}
+
+		wg.Wait()
+		assert.Equal(t, cache.Get(key), "value")
+		assert.Equal(t, 1, missCount)
+	})
 }
