@@ -9,10 +9,12 @@ import (
 	"github.com/aws/aws-sdk-go/service/cloudfront"
 	"github.com/cloudskiff/driftctl/mocks"
 	"github.com/cloudskiff/driftctl/pkg/filter"
+	"github.com/cloudskiff/driftctl/pkg/remote/alerts"
 	"github.com/cloudskiff/driftctl/pkg/remote/aws"
 	"github.com/cloudskiff/driftctl/pkg/remote/aws/repository"
 	"github.com/cloudskiff/driftctl/pkg/remote/cache"
 	"github.com/cloudskiff/driftctl/pkg/remote/common"
+	remoteerr "github.com/cloudskiff/driftctl/pkg/remote/error"
 	"github.com/cloudskiff/driftctl/pkg/resource"
 	resourceaws "github.com/cloudskiff/driftctl/pkg/resource/aws"
 	"github.com/cloudskiff/driftctl/pkg/terraform"
@@ -20,6 +22,7 @@ import (
 	"github.com/cloudskiff/driftctl/test/goldenfile"
 	testresource "github.com/cloudskiff/driftctl/test/resource"
 	terraform2 "github.com/cloudskiff/driftctl/test/terraform"
+	"github.com/pkg/errors"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/mock"
 )
@@ -28,20 +31,20 @@ func TestCloudfrontDistribution(t *testing.T) {
 	tests := []struct {
 		test    string
 		dirName string
-		mocks   func(repository *repository.MockCloudfrontRepository)
+		mocks   func(*repository.MockCloudfrontRepository, *mocks.AlerterInterface)
 		wantErr error
 	}{
 		{
 			test:    "no cloudfront distributions",
 			dirName: "aws_cloudfront_distribution_empty",
-			mocks: func(repository *repository.MockCloudfrontRepository) {
+			mocks: func(repository *repository.MockCloudfrontRepository, alerter *mocks.AlerterInterface) {
 				repository.On("ListAllDistributions").Return([]*cloudfront.DistributionSummary{}, nil)
 			},
 		},
 		{
 			test:    "single cloudfront distribution",
 			dirName: "aws_cloudfront_distribution_single",
-			mocks: func(repository *repository.MockCloudfrontRepository) {
+			mocks: func(repository *repository.MockCloudfrontRepository, alerter *mocks.AlerterInterface) {
 				repository.On("ListAllDistributions").Return([]*cloudfront.DistributionSummary{
 					{Id: awssdk.String("E1M9CNS0XSHI19")},
 				}, nil)
@@ -50,8 +53,11 @@ func TestCloudfrontDistribution(t *testing.T) {
 		{
 			test:    "cannot list cloudfront distributions",
 			dirName: "aws_cloudfront_distribution_list",
-			mocks: func(repository *repository.MockCloudfrontRepository) {
-				repository.On("ListAllDistributions").Return(nil, awserr.NewRequestFailure(nil, 403, ""))
+			mocks: func(repository *repository.MockCloudfrontRepository, alerter *mocks.AlerterInterface) {
+				awsError := awserr.NewRequestFailure(awserr.New("AccessDeniedException", "", errors.New("")), 400, "")
+				repository.On("ListAllDistributions").Return(nil, awsError)
+
+				alerter.On("SendAlert", resourceaws.AwsCloudfrontDistributionResourceType, alerts.NewRemoteAccessDeniedAlert(common.RemoteAWSTerraform, remoteerr.NewResourceListingErrorWithType(awsError, resourceaws.AwsCloudfrontDistributionResourceType, resourceaws.AwsCloudfrontDistributionResourceType), alerts.EnumerationPhase)).Return()
 			},
 			wantErr: nil,
 		},
@@ -76,9 +82,9 @@ func TestCloudfrontDistribution(t *testing.T) {
 
 			// Initialize mocks
 			alerter := &mocks.AlerterInterface{}
-			alerter.On("SendAlert", mock.Anything, mock.Anything).Maybe().Return()
 			fakeRepo := &repository.MockCloudfrontRepository{}
-			c.mocks(fakeRepo)
+			c.mocks(fakeRepo, alerter)
+
 			var repo repository.CloudfrontRepository = fakeRepo
 			providerVersion := "3.19.0"
 			realProvider, err := terraform2.InitTestAwsProvider(providerLibrary, providerVersion)
@@ -111,6 +117,8 @@ func TestCloudfrontDistribution(t *testing.T) {
 				return
 			}
 			test.TestAgainstGoldenFile(got, resourceaws.AwsCloudfrontDistributionResourceType, c.dirName, provider, deserializer, shouldUpdate, tt)
+			alerter.AssertExpectations(tt)
+			fakeRepo.AssertExpectations(tt)
 		})
 	}
 }
