@@ -9,10 +9,12 @@ import (
 	"github.com/aws/aws-sdk-go/service/ecr"
 	"github.com/cloudskiff/driftctl/mocks"
 	"github.com/cloudskiff/driftctl/pkg/filter"
+	"github.com/cloudskiff/driftctl/pkg/remote/alerts"
 	"github.com/cloudskiff/driftctl/pkg/remote/aws"
 	"github.com/cloudskiff/driftctl/pkg/remote/aws/repository"
 	"github.com/cloudskiff/driftctl/pkg/remote/cache"
 	"github.com/cloudskiff/driftctl/pkg/remote/common"
+	remoteerr "github.com/cloudskiff/driftctl/pkg/remote/error"
 	"github.com/cloudskiff/driftctl/pkg/resource"
 	resourceaws "github.com/cloudskiff/driftctl/pkg/resource/aws"
 	"github.com/cloudskiff/driftctl/pkg/terraform"
@@ -20,6 +22,7 @@ import (
 	"github.com/cloudskiff/driftctl/test/goldenfile"
 	testresource "github.com/cloudskiff/driftctl/test/resource"
 	terraform2 "github.com/cloudskiff/driftctl/test/terraform"
+	"github.com/pkg/errors"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/mock"
 )
@@ -28,13 +31,13 @@ func TestECRRepository(t *testing.T) {
 	tests := []struct {
 		test    string
 		dirName string
-		mocks   func(repository *repository.MockECRRepository)
+		mocks   func(*repository.MockECRRepository, *mocks.AlerterInterface)
 		err     error
 	}{
 		{
 			test:    "no repository",
 			dirName: "aws_ecr_repository_empty",
-			mocks: func(client *repository.MockECRRepository) {
+			mocks: func(client *repository.MockECRRepository, alerter *mocks.AlerterInterface) {
 				client.On("ListAllRepositories").Return([]*ecr.Repository{}, nil)
 			},
 			err: nil,
@@ -42,7 +45,7 @@ func TestECRRepository(t *testing.T) {
 		{
 			test:    "multiple repositories",
 			dirName: "aws_ecr_repository_multiple",
-			mocks: func(client *repository.MockECRRepository) {
+			mocks: func(client *repository.MockECRRepository, alerter *mocks.AlerterInterface) {
 				client.On("ListAllRepositories").Return([]*ecr.Repository{
 					{RepositoryName: awssdk.String("test_ecr")},
 					{RepositoryName: awssdk.String("bar")},
@@ -53,8 +56,11 @@ func TestECRRepository(t *testing.T) {
 		{
 			test:    "cannot list repository",
 			dirName: "aws_ecr_repository_empty",
-			mocks: func(client *repository.MockECRRepository) {
-				client.On("ListAllRepositories").Return(nil, awserr.NewRequestFailure(nil, 403, ""))
+			mocks: func(client *repository.MockECRRepository, alerter *mocks.AlerterInterface) {
+				awsError := awserr.NewRequestFailure(awserr.New("AccessDeniedException", "", errors.New("")), 403, "")
+				client.On("ListAllRepositories").Return(nil, awsError)
+
+				alerter.On("SendAlert", resourceaws.AwsEcrRepositoryResourceType, alerts.NewRemoteAccessDeniedAlert(common.RemoteAWSTerraform, remoteerr.NewResourceListingErrorWithType(awsError, resourceaws.AwsEcrRepositoryResourceType, resourceaws.AwsEcrRepositoryResourceType), alerts.EnumerationPhase)).Return()
 			},
 			err: nil,
 		},
@@ -79,9 +85,9 @@ func TestECRRepository(t *testing.T) {
 
 			// Initialize mocks
 			alerter := &mocks.AlerterInterface{}
-			alerter.On("SendAlert", mock.Anything, mock.Anything).Maybe().Return()
 			fakeRepo := &repository.MockECRRepository{}
-			c.mocks(fakeRepo)
+			c.mocks(fakeRepo, alerter)
+
 			var repo repository.ECRRepository = fakeRepo
 			providerVersion := "3.19.0"
 			realProvider, err := terraform2.InitTestAwsProvider(providerLibrary, providerVersion)
@@ -114,6 +120,8 @@ func TestECRRepository(t *testing.T) {
 				return
 			}
 			test.TestAgainstGoldenFile(got, resourceaws.AwsEcrRepositoryResourceType, c.dirName, provider, deserializer, shouldUpdate, tt)
+			alerter.AssertExpectations(tt)
+			fakeRepo.AssertExpectations(tt)
 		})
 	}
 }
