@@ -22,13 +22,13 @@ func (g *GithubBranchProtectionEnumerator) SupportedType() resource.ResourceType
 	return github.GithubBranchProtectionResourceType
 }
 
-func (g *GithubBranchProtectionEnumerator) Enumerate() ([]resource.Resource, error) {
+func (g *GithubBranchProtectionEnumerator) Enumerate() ([]*resource.Resource, error) {
 	ids, err := g.repository.ListBranchProtection()
 	if err != nil {
 		return nil, remoteerror.NewResourceListingError(err, string(g.SupportedType()))
 	}
 
-	results := make([]resource.Resource, len(ids))
+	results := make([]*resource.Resource, len(ids))
 
 	for _, id := range ids {
 		results = append(
