@@ -9,12 +9,15 @@ import (
 	"github.com/aws/aws-sdk-go/service/s3"
 	"github.com/cloudskiff/driftctl/mocks"
 	"github.com/cloudskiff/driftctl/pkg/filter"
+	"github.com/cloudskiff/driftctl/pkg/remote/alerts"
 	"github.com/cloudskiff/driftctl/pkg/remote/aws"
 	"github.com/cloudskiff/driftctl/pkg/remote/cache"
 	"github.com/cloudskiff/driftctl/pkg/remote/common"
+	remoteerr "github.com/cloudskiff/driftctl/pkg/remote/error"
 	tf "github.com/cloudskiff/driftctl/pkg/remote/terraform"
 	testresource "github.com/cloudskiff/driftctl/test/resource"
 	terraform2 "github.com/cloudskiff/driftctl/test/terraform"
+	"github.com/pkg/errors"
 	"github.com/stretchr/testify/mock"
 
 	"github.com/cloudskiff/driftctl/pkg/remote/aws/client"
@@ -33,12 +36,12 @@ func TestS3Bucket(t *testing.T) {
 	tests := []struct {
 		test    string
 		dirName string
-		mocks   func(repository *repository.MockS3Repository)
+		mocks   func(*repository.MockS3Repository, *mocks.AlerterInterface)
 		wantErr error
 	}{
 		{
 			test: "multiple bucket", dirName: "aws_s3_bucket_multiple",
-			mocks: func(repository *repository.MockS3Repository) {
+			mocks: func(repository *repository.MockS3Repository, alerter *mocks.AlerterInterface) {
 				repository.On(
 					"ListAllBuckets",
 				).Return([]*s3.Bucket{
@@ -74,8 +77,11 @@ func TestS3Bucket(t *testing.T) {
 		},
 		{
 			test: "cannot list bucket", dirName: "s3_bucket_list",
-			mocks: func(repository *repository.MockS3Repository) {
-				repository.On("ListAllBuckets").Return(nil, awserr.NewRequestFailure(nil, 403, ""))
+			mocks: func(repository *repository.MockS3Repository, alerter *mocks.AlerterInterface) {
+				awsError := awserr.NewRequestFailure(awserr.New("AccessDeniedException", "", errors.New("")), 403, "")
+				repository.On("ListAllBuckets").Return(nil, awsError)
+
+				alerter.On("SendAlert", resourceaws.AwsS3BucketResourceType, alerts.NewRemoteAccessDeniedAlert(common.RemoteAWSTerraform, remoteerr.NewResourceListingErrorWithType(awsError, resourceaws.AwsS3BucketResourceType, resourceaws.AwsS3BucketResourceType), alerts.EnumerationPhase)).Return()
 			},
 			wantErr: nil,
 		},
@@ -100,9 +106,8 @@ func TestS3Bucket(t *testing.T) {
 
 			// Initialize mocks
 			alerter := &mocks.AlerterInterface{}
-			alerter.On("SendAlert", mock.Anything, mock.Anything).Maybe().Return()
 			fakeRepo := &repository.MockS3Repository{}
-			c.mocks(fakeRepo)
+			c.mocks(fakeRepo, alerter)
 			var repo repository.S3Repository = fakeRepo
 			providerVersion := "3.19.0"
 			realProvider, err := terraform2.InitTestAwsProvider(providerLibrary, providerVersion)
@@ -126,7 +131,7 @@ func TestS3Bucket(t *testing.T) {
 				Name:         "test",
 				DefaultAlias: "eu-west-3",
 			}, alerter))
-			remoteLibrary.AddDetailsFetcher(resourceaws.AwsS3BucketResourceType, aws.NewS3BucketDetailsFetcher(provider, deserializer))
+			remoteLibrary.AddDetailsFetcher(resourceaws.AwsS3BucketResourceType, common.NewGenericDetailsFetcher(resourceaws.AwsS3BucketResourceType, provider, deserializer))
 
 			testFilter := &filter.MockFilter{}
 			testFilter.On("IsTypeIgnored", mock.Anything).Return(false)
@@ -138,6 +143,8 @@ func TestS3Bucket(t *testing.T) {
 				return
 			}
 			test.TestAgainstGoldenFile(got, resourceaws.AwsS3BucketResourceType, c.dirName, provider, deserializer, shouldUpdate, tt)
+			alerter.AssertExpectations(tt)
+			fakeRepo.AssertExpectations(tt)
 		})
 	}
 }
@@ -147,12 +154,12 @@ func TestS3BucketInventory(t *testing.T) {
 	tests := []struct {
 		test    string
 		dirName string
-		mocks   func(repository *repository.MockS3Repository)
+		mocks   func(*repository.MockS3Repository, *mocks.AlerterInterface)
 		wantErr error
 	}{
 		{
 			test: "multiple bucket with multiple inventories", dirName: "s3_bucket_inventories_multiple",
-			mocks: func(repository *repository.MockS3Repository) {
+			mocks: func(repository *repository.MockS3Repository, alerter *mocks.AlerterInterface) {
 				repository.On(
 					"ListAllBuckets",
 				).Return([]*s3.Bucket{
@@ -200,14 +207,17 @@ func TestS3BucketInventory(t *testing.T) {
 		},
 		{
 			test: "cannot list bucket", dirName: "s3_bucket_inventories_list_bucket",
-			mocks: func(repository *repository.MockS3Repository) {
-				repository.On("ListAllBuckets").Return(nil, awserr.NewRequestFailure(nil, 403, ""))
+			mocks: func(repository *repository.MockS3Repository, alerter *mocks.AlerterInterface) {
+				awsError := awserr.NewRequestFailure(awserr.New("AccessDeniedException", "", errors.New("")), 403, "")
+				repository.On("ListAllBuckets").Return(nil, awsError)
+
+				alerter.On("SendAlert", resourceaws.AwsS3BucketInventoryResourceType, alerts.NewRemoteAccessDeniedAlert(common.RemoteAWSTerraform, remoteerr.NewResourceListingErrorWithType(awsError, resourceaws.AwsS3BucketInventoryResourceType, resourceaws.AwsS3BucketResourceType), alerts.EnumerationPhase)).Return()
 			},
 			wantErr: nil,
 		},
 		{
 			test: "cannot list bucket inventories", dirName: "s3_bucket_inventories_list_inventories",
-			mocks: func(repository *repository.MockS3Repository) {
+			mocks: func(repository *repository.MockS3Repository, alerter *mocks.AlerterInterface) {
 				repository.On("ListAllBuckets").Return(
 					[]*s3.Bucket{
 						{Name: awssdk.String("bucket-martin-test-drift")},
@@ -221,14 +231,17 @@ func TestS3BucketInventory(t *testing.T) {
 					"eu-west-3",
 					nil,
 				)
+				awsError := awserr.NewRequestFailure(awserr.New("AccessDeniedException", "", errors.New("")), 403, "")
 				repository.On(
 					"ListBucketInventoryConfigurations",
 					&s3.Bucket{Name: awssdk.String("bucket-martin-test-drift")},
 					"eu-west-3",
 				).Return(
 					nil,
-					awserr.NewRequestFailure(nil, 403, ""),
+					awsError,
 				)
+
+				alerter.On("SendAlert", resourceaws.AwsS3BucketInventoryResourceType, alerts.NewRemoteAccessDeniedAlert(common.RemoteAWSTerraform, remoteerr.NewResourceListingErrorWithType(awsError, resourceaws.AwsS3BucketInventoryResourceType, resourceaws.AwsS3BucketInventoryResourceType), alerts.EnumerationPhase)).Return()
 			},
 			wantErr: nil,
 		},
@@ -253,9 +266,8 @@ func TestS3BucketInventory(t *testing.T) {
 
 			// Initialize mocks
 			alerter := &mocks.AlerterInterface{}
-			alerter.On("SendAlert", mock.Anything, mock.Anything).Maybe().Return()
 			fakeRepo := &repository.MockS3Repository{}
-			c.mocks(fakeRepo)
+			c.mocks(fakeRepo, alerter)
 			var repo repository.S3Repository = fakeRepo
 			providerVersion := "3.19.0"
 			realProvider, err := terraform2.InitTestAwsProvider(providerLibrary, providerVersion)
@@ -279,7 +291,7 @@ func TestS3BucketInventory(t *testing.T) {
 				Name:         "test",
 				DefaultAlias: "eu-west-3",
 			}, alerter))
-			remoteLibrary.AddDetailsFetcher(resourceaws.AwsS3BucketInventoryResourceType, aws.NewS3BucketInventoryDetailsFetcher(provider, deserializer))
+			remoteLibrary.AddDetailsFetcher(resourceaws.AwsS3BucketInventoryResourceType, common.NewGenericDetailsFetcher(resourceaws.AwsS3BucketInventoryResourceType, provider, deserializer))
 
 			testFilter := &filter.MockFilter{}
 			testFilter.On("IsTypeIgnored", mock.Anything).Return(false)
@@ -291,6 +303,8 @@ func TestS3BucketInventory(t *testing.T) {
 				return
 			}
 			test.TestAgainstGoldenFile(got, resourceaws.AwsS3BucketInventoryResourceType, c.dirName, provider, deserializer, shouldUpdate, tt)
+			alerter.AssertExpectations(tt)
+			fakeRepo.AssertExpectations(tt)
 		})
 	}
 }
@@ -300,13 +314,13 @@ func TestS3BucketNotification(t *testing.T) {
 	tests := []struct {
 		test    string
 		dirName string
-		mocks   func(repository *repository.MockS3Repository)
+		mocks   func(*repository.MockS3Repository, *mocks.AlerterInterface)
 		wantErr error
 	}{
 		{
 			test:    "single bucket without notifications",
 			dirName: "s3_bucket_notifications_no_notif",
-			mocks: func(repository *repository.MockS3Repository) {
+			mocks: func(repository *repository.MockS3Repository, alerter *mocks.AlerterInterface) {
 				repository.On(
 					"ListAllBuckets",
 				).Return([]*s3.Bucket{
@@ -333,7 +347,7 @@ func TestS3BucketNotification(t *testing.T) {
 		},
 		{
 			test: "multiple bucket with notifications", dirName: "s3_bucket_notifications_multiple",
-			mocks: func(repository *repository.MockS3Repository) {
+			mocks: func(repository *repository.MockS3Repository, alerter *mocks.AlerterInterface) {
 				repository.On(
 					"ListAllBuckets",
 				).Return([]*s3.Bucket{
@@ -387,7 +401,7 @@ func TestS3BucketNotification(t *testing.T) {
 		},
 		{
 			test: "Cannot get bucket notification", dirName: "s3_bucket_notifications_list_bucket",
-			mocks: func(repository *repository.MockS3Repository) {
+			mocks: func(repository *repository.MockS3Repository, alerter *mocks.AlerterInterface) {
 				repository.On(
 					"ListAllBuckets",
 				).Return([]*s3.Bucket{
@@ -400,14 +414,20 @@ func TestS3BucketNotification(t *testing.T) {
 					"eu-west-3",
 					nil,
 				)
-				repository.On("GetBucketNotification", "dritftctl-test-notifications-error", "eu-west-3").Return(nil, awserr.NewRequestFailure(nil, 403, ""))
+				awsError := awserr.NewRequestFailure(awserr.New("AccessDeniedException", "", errors.New("")), 403, "")
+				repository.On("GetBucketNotification", "dritftctl-test-notifications-error", "eu-west-3").Return(nil, awsError)
+
+				alerter.On("SendAlert", "aws_s3_bucket_notification.dritftctl-test-notifications-error", alerts.NewRemoteAccessDeniedAlert(common.RemoteAWSTerraform, remoteerr.NewResourceListingErrorWithType(awsError, "aws_s3_bucket_notification.dritftctl-test-notifications-error", resourceaws.AwsS3BucketNotificationResourceType), alerts.EnumerationPhase)).Return()
 			},
 			wantErr: nil,
 		},
 		{
 			test: "Cannot list bucket", dirName: "s3_bucket_notifications_list_bucket",
-			mocks: func(repository *repository.MockS3Repository) {
-				repository.On("ListAllBuckets").Return(nil, awserr.NewRequestFailure(nil, 403, ""))
+			mocks: func(repository *repository.MockS3Repository, alerter *mocks.AlerterInterface) {
+				awsError := awserr.NewRequestFailure(awserr.New("AccessDeniedException", "", errors.New("")), 403, "")
+				repository.On("ListAllBuckets").Return(nil, awsError)
+
+				alerter.On("SendAlert", resourceaws.AwsS3BucketNotificationResourceType, alerts.NewRemoteAccessDeniedAlert(common.RemoteAWSTerraform, remoteerr.NewResourceListingErrorWithType(awsError, resourceaws.AwsS3BucketNotificationResourceType, resourceaws.AwsS3BucketResourceType), alerts.EnumerationPhase)).Return()
 			},
 			wantErr: nil,
 		},
@@ -432,9 +452,8 @@ func TestS3BucketNotification(t *testing.T) {
 
 			// Initialize mocks
 			alerter := &mocks.AlerterInterface{}
-			alerter.On("SendAlert", mock.Anything, mock.Anything).Maybe().Return()
 			fakeRepo := &repository.MockS3Repository{}
-			c.mocks(fakeRepo)
+			c.mocks(fakeRepo, alerter)
 			var repo repository.S3Repository = fakeRepo
 			providerVersion := "3.19.0"
 			realProvider, err := terraform2.InitTestAwsProvider(providerLibrary, providerVersion)
@@ -458,7 +477,7 @@ func TestS3BucketNotification(t *testing.T) {
 				Name:         "test",
 				DefaultAlias: "eu-west-3",
 			}, alerter))
-			remoteLibrary.AddDetailsFetcher(resourceaws.AwsS3BucketNotificationResourceType, aws.NewS3BucketNotificationDetailsFetcher(provider, deserializer))
+			remoteLibrary.AddDetailsFetcher(resourceaws.AwsS3BucketNotificationResourceType, common.NewGenericDetailsFetcher(resourceaws.AwsS3BucketNotificationResourceType, provider, deserializer))
 
 			testFilter := &filter.MockFilter{}
 			testFilter.On("IsTypeIgnored", mock.Anything).Return(false)
@@ -470,6 +489,8 @@ func TestS3BucketNotification(t *testing.T) {
 				return
 			}
 			test.TestAgainstGoldenFile(got, resourceaws.AwsS3BucketNotificationResourceType, c.dirName, provider, deserializer, shouldUpdate, tt)
+			alerter.AssertExpectations(tt)
+			fakeRepo.AssertExpectations(tt)
 		})
 	}
 }
@@ -479,12 +500,12 @@ func TestS3BucketMetrics(t *testing.T) {
 	tests := []struct {
 		test    string
 		dirName string
-		mocks   func(repository *repository.MockS3Repository)
+		mocks   func(*repository.MockS3Repository, *mocks.AlerterInterface)
 		wantErr error
 	}{
 		{
 			test: "multiple bucket with multiple metrics", dirName: "s3_bucket_metrics_multiple",
-			mocks: func(repository *repository.MockS3Repository) {
+			mocks: func(repository *repository.MockS3Repository, alerter *mocks.AlerterInterface) {
 				repository.On(
 					"ListAllBuckets",
 				).Return([]*s3.Bucket{
@@ -532,14 +553,17 @@ func TestS3BucketMetrics(t *testing.T) {
 		},
 		{
 			test: "cannot list bucket", dirName: "s3_bucket_metrics_list_bucket",
-			mocks: func(repository *repository.MockS3Repository) {
-				repository.On("ListAllBuckets").Return(nil, awserr.NewRequestFailure(nil, 403, ""))
+			mocks: func(repository *repository.MockS3Repository, alerter *mocks.AlerterInterface) {
+				awsError := awserr.NewRequestFailure(awserr.New("AccessDeniedException", "", errors.New("")), 403, "")
+				repository.On("ListAllBuckets").Return(nil, awsError)
+
+				alerter.On("SendAlert", resourceaws.AwsS3BucketMetricResourceType, alerts.NewRemoteAccessDeniedAlert(common.RemoteAWSTerraform, remoteerr.NewResourceListingErrorWithType(awsError, resourceaws.AwsS3BucketMetricResourceType, resourceaws.AwsS3BucketResourceType), alerts.EnumerationPhase)).Return()
 			},
 			wantErr: nil,
 		},
 		{
 			test: "cannot list metrics", dirName: "s3_bucket_metrics_list_metrics",
-			mocks: func(repository *repository.MockS3Repository) {
+			mocks: func(repository *repository.MockS3Repository, alerter *mocks.AlerterInterface) {
 				repository.On("ListAllBuckets").Return(
 					[]*s3.Bucket{
 						{Name: awssdk.String("bucket-martin-test-drift")},
@@ -554,15 +578,17 @@ func TestS3BucketMetrics(t *testing.T) {
 					nil,
 				)
 
+				awsError := awserr.NewRequestFailure(awserr.New("AccessDeniedException", "", errors.New("")), 403, "")
 				repository.On(
 					"ListBucketMetricsConfigurations",
 					&s3.Bucket{Name: awssdk.String("bucket-martin-test-drift")},
 					"eu-west-3",
 				).Return(
 					nil,
-					awserr.NewRequestFailure(nil, 403, ""),
+					awsError,
 				)
 
+				alerter.On("SendAlert", resourceaws.AwsS3BucketMetricResourceType, alerts.NewRemoteAccessDeniedAlert(common.RemoteAWSTerraform, remoteerr.NewResourceListingErrorWithType(awsError, resourceaws.AwsS3BucketMetricResourceType, resourceaws.AwsS3BucketMetricResourceType), alerts.EnumerationPhase)).Return()
 			},
 			wantErr: nil,
 		},
@@ -587,9 +613,8 @@ func TestS3BucketMetrics(t *testing.T) {
 
 			// Initialize mocks
 			alerter := &mocks.AlerterInterface{}
-			alerter.On("SendAlert", mock.Anything, mock.Anything).Maybe().Return()
 			fakeRepo := &repository.MockS3Repository{}
-			c.mocks(fakeRepo)
+			c.mocks(fakeRepo, alerter)
 			var repo repository.S3Repository = fakeRepo
 			providerVersion := "3.19.0"
 			realProvider, err := terraform2.InitTestAwsProvider(providerLibrary, providerVersion)
@@ -613,7 +638,7 @@ func TestS3BucketMetrics(t *testing.T) {
 				Name:         "test",
 				DefaultAlias: "eu-west-3",
 			}, alerter))
-			remoteLibrary.AddDetailsFetcher(resourceaws.AwsS3BucketMetricResourceType, aws.NewS3BucketMetricsDetailsFetcher(provider, deserializer))
+			remoteLibrary.AddDetailsFetcher(resourceaws.AwsS3BucketMetricResourceType, common.NewGenericDetailsFetcher(resourceaws.AwsS3BucketMetricResourceType, provider, deserializer))
 
 			testFilter := &filter.MockFilter{}
 			testFilter.On("IsTypeIgnored", mock.Anything).Return(false)
@@ -625,6 +650,8 @@ func TestS3BucketMetrics(t *testing.T) {
 				return
 			}
 			test.TestAgainstGoldenFile(got, resourceaws.AwsS3BucketMetricResourceType, c.dirName, provider, deserializer, shouldUpdate, tt)
+			alerter.AssertExpectations(tt)
+			fakeRepo.AssertExpectations(tt)
 		})
 	}
 }
@@ -634,13 +661,13 @@ func TestS3BucketPolicy(t *testing.T) {
 	tests := []struct {
 		test    string
 		dirName string
-		mocks   func(repository *repository.MockS3Repository)
+		mocks   func(*repository.MockS3Repository, *mocks.AlerterInterface)
 		wantErr error
 	}{
 		{
 			test:    "single bucket without policy",
 			dirName: "s3_bucket_policy_no_policy",
-			mocks: func(repository *repository.MockS3Repository) {
+			mocks: func(repository *repository.MockS3Repository, alerter *mocks.AlerterInterface) {
 				repository.On(
 					"ListAllBuckets",
 				).Return([]*s3.Bucket{
@@ -667,7 +694,7 @@ func TestS3BucketPolicy(t *testing.T) {
 		},
 		{
 			test: "multiple bucket with policies", dirName: "s3_bucket_policies_multiple",
-			mocks: func(repository *repository.MockS3Repository) {
+			mocks: func(repository *repository.MockS3Repository, alerter *mocks.AlerterInterface) {
 				repository.On(
 					"ListAllBuckets",
 				).Return([]*s3.Bucket{
@@ -715,8 +742,11 @@ func TestS3BucketPolicy(t *testing.T) {
 		},
 		{
 			test: "cannot list bucket", dirName: "s3_bucket_policies_list_bucket",
-			mocks: func(repository *repository.MockS3Repository) {
-				repository.On("ListAllBuckets").Return(nil, awserr.NewRequestFailure(nil, 403, ""))
+			mocks: func(repository *repository.MockS3Repository, alerter *mocks.AlerterInterface) {
+				awsError := awserr.NewRequestFailure(awserr.New("AccessDeniedException", "", errors.New("")), 403, "")
+				repository.On("ListAllBuckets").Return(nil, awsError)
+
+				alerter.On("SendAlert", resourceaws.AwsS3BucketPolicyResourceType, alerts.NewRemoteAccessDeniedAlert(common.RemoteAWSTerraform, remoteerr.NewResourceListingErrorWithType(awsError, resourceaws.AwsS3BucketPolicyResourceType, resourceaws.AwsS3BucketResourceType), alerts.EnumerationPhase)).Return()
 			},
 			wantErr: nil,
 		},
@@ -741,9 +771,8 @@ func TestS3BucketPolicy(t *testing.T) {
 
 			// Initialize mocks
 			alerter := &mocks.AlerterInterface{}
-			alerter.On("SendAlert", mock.Anything, mock.Anything).Maybe().Return()
 			fakeRepo := &repository.MockS3Repository{}
-			c.mocks(fakeRepo)
+			c.mocks(fakeRepo, alerter)
 			var repo repository.S3Repository = fakeRepo
 			providerVersion := "3.19.0"
 			realProvider, err := terraform2.InitTestAwsProvider(providerLibrary, providerVersion)
@@ -767,7 +796,7 @@ func TestS3BucketPolicy(t *testing.T) {
 				Name:         "test",
 				DefaultAlias: "eu-west-3",
 			}, alerter))
-			remoteLibrary.AddDetailsFetcher(resourceaws.AwsS3BucketPolicyResourceType, aws.NewS3BucketPolicyDetailsFetcher(provider, deserializer))
+			remoteLibrary.AddDetailsFetcher(resourceaws.AwsS3BucketPolicyResourceType, common.NewGenericDetailsFetcher(resourceaws.AwsS3BucketPolicyResourceType, provider, deserializer))
 
 			testFilter := &filter.MockFilter{}
 			testFilter.On("IsTypeIgnored", mock.Anything).Return(false)
@@ -779,6 +808,8 @@ func TestS3BucketPolicy(t *testing.T) {
 				return
 			}
 			test.TestAgainstGoldenFile(got, resourceaws.AwsS3BucketPolicyResourceType, c.dirName, provider, deserializer, shouldUpdate, tt)
+			alerter.AssertExpectations(tt)
+			fakeRepo.AssertExpectations(tt)
 		})
 	}
 }
@@ -788,13 +819,13 @@ func TestS3BucketAnalytic(t *testing.T) {
 	tests := []struct {
 		test    string
 		dirName string
-		mocks   func(repository *repository.MockS3Repository)
+		mocks   func(*repository.MockS3Repository, *mocks.AlerterInterface)
 		wantErr error
 	}{
 		{
 			test:    "multiple bucket with multiple analytics",
 			dirName: "aws_s3_bucket_analytics_multiple",
-			mocks: func(repository *repository.MockS3Repository) {
+			mocks: func(repository *repository.MockS3Repository, alerter *mocks.AlerterInterface) {
 				repository.On(
 					"ListAllBuckets",
 				).Return([]*s3.Bucket{
@@ -840,17 +871,19 @@ func TestS3BucketAnalytic(t *testing.T) {
 				)
 			},
 		},
-
 		{
 			test: "cannot list bucket", dirName: "aws_s3_bucket_analytics_list_bucket",
-			mocks: func(repository *repository.MockS3Repository) {
-				repository.On("ListAllBuckets").Return(nil, awserr.NewRequestFailure(nil, 403, ""))
+			mocks: func(repository *repository.MockS3Repository, alerter *mocks.AlerterInterface) {
+				awsError := awserr.NewRequestFailure(awserr.New("AccessDeniedException", "", errors.New("")), 403, "")
+				repository.On("ListAllBuckets").Return(nil, awsError)
+
+				alerter.On("SendAlert", resourceaws.AwsS3BucketAnalyticsConfigurationResourceType, alerts.NewRemoteAccessDeniedAlert(common.RemoteAWSTerraform, remoteerr.NewResourceListingErrorWithType(awsError, resourceaws.AwsS3BucketAnalyticsConfigurationResourceType, resourceaws.AwsS3BucketResourceType), alerts.EnumerationPhase)).Return()
 			},
 			wantErr: nil,
 		},
 		{
 			test: "cannot list Analytics", dirName: "aws_s3_bucket_analytics_list_analytics",
-			mocks: func(repository *repository.MockS3Repository) {
+			mocks: func(repository *repository.MockS3Repository, alerter *mocks.AlerterInterface) {
 				repository.On("ListAllBuckets").Return(
 					[]*s3.Bucket{
 						{Name: awssdk.String("bucket-martin-test-drift")},
@@ -865,15 +898,17 @@ func TestS3BucketAnalytic(t *testing.T) {
 					nil,
 				)
 
+				awsError := awserr.NewRequestFailure(awserr.New("AccessDeniedException", "", errors.New("")), 403, "")
 				repository.On(
 					"ListBucketAnalyticsConfigurations",
 					&s3.Bucket{Name: awssdk.String("bucket-martin-test-drift")},
 					"eu-west-3",
 				).Return(
 					nil,
-					awserr.NewRequestFailure(nil, 403, ""),
+					awsError,
 				)
 
+				alerter.On("SendAlert", resourceaws.AwsS3BucketAnalyticsConfigurationResourceType, alerts.NewRemoteAccessDeniedAlert(common.RemoteAWSTerraform, remoteerr.NewResourceListingErrorWithType(awsError, resourceaws.AwsS3BucketAnalyticsConfigurationResourceType, resourceaws.AwsS3BucketAnalyticsConfigurationResourceType), alerts.EnumerationPhase)).Return()
 			},
 			wantErr: nil,
 		},
@@ -898,9 +933,8 @@ func TestS3BucketAnalytic(t *testing.T) {
 
 			// Initialize mocks
 			alerter := &mocks.AlerterInterface{}
-			alerter.On("SendAlert", mock.Anything, mock.Anything).Maybe().Return()
 			fakeRepo := &repository.MockS3Repository{}
-			c.mocks(fakeRepo)
+			c.mocks(fakeRepo, alerter)
 			var repo repository.S3Repository = fakeRepo
 			providerVersion := "3.19.0"
 			realProvider, err := terraform2.InitTestAwsProvider(providerLibrary, providerVersion)
@@ -924,7 +958,7 @@ func TestS3BucketAnalytic(t *testing.T) {
 				Name:         "test",
 				DefaultAlias: "eu-west-3",
 			}, alerter))
-			remoteLibrary.AddDetailsFetcher(resourceaws.AwsS3BucketAnalyticsConfigurationResourceType, aws.NewS3BucketAnalyticDetailsFetcher(provider, deserializer))
+			remoteLibrary.AddDetailsFetcher(resourceaws.AwsS3BucketAnalyticsConfigurationResourceType, common.NewGenericDetailsFetcher(resourceaws.AwsS3BucketAnalyticsConfigurationResourceType, provider, deserializer))
 
 			testFilter := &filter.MockFilter{}
 			testFilter.On("IsTypeIgnored", mock.Anything).Return(false)
@@ -936,6 +970,8 @@ func TestS3BucketAnalytic(t *testing.T) {
 				return
 			}
 			test.TestAgainstGoldenFile(got, resourceaws.AwsS3BucketAnalyticsConfigurationResourceType, c.dirName, provider, deserializer, shouldUpdate, tt)
+			alerter.AssertExpectations(tt)
+			fakeRepo.AssertExpectations(tt)
 		})
 	}
 }
