@@ -8,14 +8,15 @@ import (
 	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/sns"
 	"github.com/cloudskiff/driftctl/mocks"
-	"github.com/cloudskiff/driftctl/pkg/alerter"
 	"github.com/cloudskiff/driftctl/pkg/filter"
 	"github.com/cloudskiff/driftctl/pkg/remote/alerts"
 	"github.com/cloudskiff/driftctl/pkg/remote/aws"
 	"github.com/cloudskiff/driftctl/pkg/remote/cache"
 	"github.com/cloudskiff/driftctl/pkg/remote/common"
+	remoteerr "github.com/cloudskiff/driftctl/pkg/remote/error"
 	testresource "github.com/cloudskiff/driftctl/test/resource"
 	terraform2 "github.com/cloudskiff/driftctl/test/terraform"
+	"github.com/pkg/errors"
 	"github.com/stretchr/testify/mock"
 
 	"github.com/cloudskiff/driftctl/pkg/remote/aws/repository"
@@ -33,13 +34,13 @@ func TestScanSNSTopic(t *testing.T) {
 	cases := []struct {
 		test    string
 		dirName string
-		mocks   func(client *repository.MockSNSRepository)
+		mocks   func(*repository.MockSNSRepository, *mocks.AlerterInterface)
 		err     error
 	}{
 		{
 			test:    "no SNS Topic",
 			dirName: "sns_topic_empty",
-			mocks: func(client *repository.MockSNSRepository) {
+			mocks: func(client *repository.MockSNSRepository, alerter *mocks.AlerterInterface) {
 				client.On("ListAllTopics").Return([]*sns.Topic{}, nil)
 			},
 			err: nil,
@@ -47,7 +48,7 @@ func TestScanSNSTopic(t *testing.T) {
 		{
 			test:    "Multiple SNSTopic",
 			dirName: "sns_topic_multiple",
-			mocks: func(client *repository.MockSNSRepository) {
+			mocks: func(client *repository.MockSNSRepository, alerter *mocks.AlerterInterface) {
 				client.On("ListAllTopics").Return([]*sns.Topic{
 					{TopicArn: awssdk.String("arn:aws:sns:eu-west-3:526954929923:user-updates-topic")},
 					{TopicArn: awssdk.String("arn:aws:sns:eu-west-3:526954929923:user-updates-topic2")},
@@ -59,8 +60,11 @@ func TestScanSNSTopic(t *testing.T) {
 		{
 			test:    "cannot list SNSTopic",
 			dirName: "sns_topic_empty",
-			mocks: func(client *repository.MockSNSRepository) {
-				client.On("ListAllTopics").Return(nil, awserr.NewRequestFailure(nil, 403, ""))
+			mocks: func(client *repository.MockSNSRepository, alerter *mocks.AlerterInterface) {
+				awsError := awserr.NewRequestFailure(awserr.New("AccessDeniedException", "", errors.New("")), 403, "")
+				client.On("ListAllTopics").Return(nil, awsError)
+
+				alerter.On("SendAlert", resourceaws.AwsSnsTopicResourceType, alerts.NewRemoteAccessDeniedAlert(common.RemoteAWSTerraform, remoteerr.NewResourceListingErrorWithType(awsError, resourceaws.AwsSnsTopicResourceType, resourceaws.AwsSnsTopicResourceType), alerts.EnumerationPhase)).Return()
 			},
 			err: nil,
 		},
@@ -75,20 +79,19 @@ func TestScanSNSTopic(t *testing.T) {
 		t.Run(c.test, func(tt *testing.T) {
 			shouldUpdate := c.dirName == *goldenfile.Update
 
-			session := session.Must(session.NewSessionWithOptions(session.Options{
+			sess := session.Must(session.NewSessionWithOptions(session.Options{
 				SharedConfigState: session.SharedConfigEnable,
 			}))
 
-			alerter := &mocks.AlerterInterface{}
-			alerter.On("SendAlert", mock.Anything, mock.Anything).Maybe().Return()
-
 			scanOptions := ScannerOptions{Deep: true}
 			providerLibrary := terraform.NewProviderLibrary()
 			remoteLibrary := common.NewRemoteLibrary()
 
 			// Initialize mocks
+			alerter := &mocks.AlerterInterface{}
 			fakeRepo := &repository.MockSNSRepository{}
-			c.mocks(fakeRepo)
+			c.mocks(fakeRepo, alerter)
+
 			var repo repository.SNSRepository = fakeRepo
 			providerVersion := "3.19.0"
 			realProvider, err := terraform2.InitTestAwsProvider(providerLibrary, providerVersion)
@@ -105,11 +108,11 @@ func TestScanSNSTopic(t *testing.T) {
 					t.Fatal(err)
 				}
 				provider.ShouldUpdate()
-				repo = repository.NewSNSRepository(session, cache.New(0))
+				repo = repository.NewSNSRepository(sess, cache.New(0))
 			}
 
 			remoteLibrary.AddEnumerator(aws.NewSNSTopicEnumerator(repo, factory))
-			remoteLibrary.AddDetailsFetcher(resourceaws.AwsSnsTopicResourceType, aws.NewSNSTopicDetailsFetcher(provider, deserializer))
+			remoteLibrary.AddDetailsFetcher(resourceaws.AwsSnsTopicResourceType, common.NewGenericDetailsFetcher(resourceaws.AwsSnsTopicResourceType, provider, deserializer))
 
 			testFilter := &filter.MockFilter{}
 			testFilter.On("IsTypeIgnored", mock.Anything).Return(false)
@@ -121,6 +124,8 @@ func TestScanSNSTopic(t *testing.T) {
 				return
 			}
 			test.TestAgainstGoldenFile(got, resourceaws.AwsSnsTopicResourceType, c.dirName, provider, deserializer, shouldUpdate, tt)
+			alerter.AssertExpectations(tt)
+			fakeRepo.AssertExpectations(tt)
 		})
 	}
 }
@@ -130,13 +135,13 @@ func TestSNSTopicPolicyScan(t *testing.T) {
 	cases := []struct {
 		test    string
 		dirName string
-		mocks   func(client *repository.MockSNSRepository)
+		mocks   func(*repository.MockSNSRepository, *mocks.AlerterInterface)
 		err     error
 	}{
 		{
 			test:    "no SNS Topic policy",
 			dirName: "sns_topic_policy_empty",
-			mocks: func(client *repository.MockSNSRepository) {
+			mocks: func(client *repository.MockSNSRepository, alerter *mocks.AlerterInterface) {
 				client.On("ListAllTopics").Return([]*sns.Topic{}, nil)
 			},
 			err: nil,
@@ -144,7 +149,7 @@ func TestSNSTopicPolicyScan(t *testing.T) {
 		{
 			test:    "Multiple SNSTopicPolicy",
 			dirName: "sns_topic_policy_multiple",
-			mocks: func(client *repository.MockSNSRepository) {
+			mocks: func(client *repository.MockSNSRepository, alerter *mocks.AlerterInterface) {
 				client.On("ListAllTopics").Return([]*sns.Topic{
 					{TopicArn: awssdk.String("arn:aws:sns:us-east-1:526954929923:my-topic-with-policy")},
 					{TopicArn: awssdk.String("arn:aws:sns:us-east-1:526954929923:my-topic-with-policy2")},
@@ -155,8 +160,11 @@ func TestSNSTopicPolicyScan(t *testing.T) {
 		{
 			test:    "cannot list SNSTopic",
 			dirName: "sns_topic_policy_topic_list",
-			mocks: func(client *repository.MockSNSRepository) {
-				client.On("ListAllTopics").Return(nil, awserr.NewRequestFailure(nil, 403, ""))
+			mocks: func(client *repository.MockSNSRepository, alerter *mocks.AlerterInterface) {
+				awsError := awserr.NewRequestFailure(awserr.New("AccessDeniedException", "", errors.New("")), 403, "")
+				client.On("ListAllTopics").Return(nil, awsError)
+
+				alerter.On("SendAlert", resourceaws.AwsSnsTopicPolicyResourceType, alerts.NewRemoteAccessDeniedAlert(common.RemoteAWSTerraform, remoteerr.NewResourceListingErrorWithType(awsError, resourceaws.AwsSnsTopicPolicyResourceType, resourceaws.AwsSnsTopicResourceType), alerts.EnumerationPhase)).Return()
 			},
 			err: nil,
 		},
@@ -171,20 +179,19 @@ func TestSNSTopicPolicyScan(t *testing.T) {
 		t.Run(c.test, func(tt *testing.T) {
 			shouldUpdate := c.dirName == *goldenfile.Update
 
-			session := session.Must(session.NewSessionWithOptions(session.Options{
+			sess := session.Must(session.NewSessionWithOptions(session.Options{
 				SharedConfigState: session.SharedConfigEnable,
 			}))
 
-			alerter := &mocks.AlerterInterface{}
-			alerter.On("SendAlert", mock.Anything, mock.Anything).Maybe().Return()
-
 			scanOptions := ScannerOptions{Deep: true}
 			providerLibrary := terraform.NewProviderLibrary()
 			remoteLibrary := common.NewRemoteLibrary()
 
 			// Initialize mocks
+			alerter := &mocks.AlerterInterface{}
 			fakeRepo := &repository.MockSNSRepository{}
-			c.mocks(fakeRepo)
+			c.mocks(fakeRepo, alerter)
+
 			var repo repository.SNSRepository = fakeRepo
 			providerVersion := "3.19.0"
 			realProvider, err := terraform2.InitTestAwsProvider(providerLibrary, providerVersion)
@@ -201,11 +208,11 @@ func TestSNSTopicPolicyScan(t *testing.T) {
 					t.Fatal(err)
 				}
 				provider.ShouldUpdate()
-				repo = repository.NewSNSRepository(session, cache.New(0))
+				repo = repository.NewSNSRepository(sess, cache.New(0))
 			}
 
 			remoteLibrary.AddEnumerator(aws.NewSNSTopicPolicyEnumerator(repo, factory))
-			remoteLibrary.AddDetailsFetcher(resourceaws.AwsSnsTopicPolicyResourceType, aws.NewSNSTopicPolicyDetailsFetcher(provider, deserializer))
+			remoteLibrary.AddDetailsFetcher(resourceaws.AwsSnsTopicPolicyResourceType, common.NewGenericDetailsFetcher(resourceaws.AwsSnsTopicPolicyResourceType, provider, deserializer))
 
 			testFilter := &filter.MockFilter{}
 			testFilter.On("IsTypeIgnored", mock.Anything).Return(false)
@@ -217,6 +224,8 @@ func TestSNSTopicPolicyScan(t *testing.T) {
 				return
 			}
 			test.TestAgainstGoldenFile(got, resourceaws.AwsSnsTopicPolicyResourceType, c.dirName, provider, deserializer, shouldUpdate, tt)
+			alerter.AssertExpectations(tt)
+			fakeRepo.AssertExpectations(tt)
 		})
 	}
 }
@@ -226,62 +235,53 @@ func TestSNSTopicSubscriptionScan(t *testing.T) {
 	cases := []struct {
 		test    string
 		dirName string
-		mocks   func(client *repository.MockSNSRepository)
-		alerts  alerter.Alerts
+		mocks   func(*repository.MockSNSRepository, *mocks.AlerterInterface)
 		err     error
 	}{
 		{
 			test:    "no SNS Topic Subscription",
 			dirName: "sns_topic_subscription_empty",
-			mocks: func(client *repository.MockSNSRepository) {
+			mocks: func(client *repository.MockSNSRepository, alerter *mocks.AlerterInterface) {
 				client.On("ListAllSubscriptions").Return([]*sns.Subscription{}, nil)
 			},
-			alerts: map[string][]alerter.Alert{},
-			err:    nil,
+			err: nil,
 		},
 		{
 			test:    "Multiple SNSTopic Subscription",
 			dirName: "sns_topic_subscription_multiple",
-			mocks: func(client *repository.MockSNSRepository) {
+			mocks: func(client *repository.MockSNSRepository, alerter *mocks.AlerterInterface) {
 				client.On("ListAllSubscriptions").Return([]*sns.Subscription{
 					{SubscriptionArn: awssdk.String("arn:aws:sns:us-east-1:526954929923:user-updates-topic2:c0f794c5-a009-4db4-9147-4c55959787fa")},
 					{SubscriptionArn: awssdk.String("arn:aws:sns:us-east-1:526954929923:user-updates-topic:b6e66147-2b31-4486-8d4b-2a2272264c8e")},
 				}, nil)
 			},
-			alerts: map[string][]alerter.Alert{},
-			err:    nil,
+			err: nil,
 		},
 		{
 			test:    "Multiple SNSTopic Subscription with one pending and one incorrect",
 			dirName: "sns_topic_subscription_multiple",
-			mocks: func(client *repository.MockSNSRepository) {
+			mocks: func(client *repository.MockSNSRepository, alerter *mocks.AlerterInterface) {
 				client.On("ListAllSubscriptions").Return([]*sns.Subscription{
 					{SubscriptionArn: awssdk.String("PendingConfirmation"), Endpoint: awssdk.String("TEST")},
 					{SubscriptionArn: awssdk.String("Incorrect"), Endpoint: awssdk.String("INCORRECT")},
 					{SubscriptionArn: awssdk.String("arn:aws:sns:us-east-1:526954929923:user-updates-topic2:c0f794c5-a009-4db4-9147-4c55959787fa")},
 					{SubscriptionArn: awssdk.String("arn:aws:sns:us-east-1:526954929923:user-updates-topic:b6e66147-2b31-4486-8d4b-2a2272264c8e")},
 				}, nil)
-			},
-			alerts: map[string][]alerter.Alert{
-				"aws_sns_topic_subscription.PendingConfirmation": []alerter.Alert{
-					aws.NewWrongArnTopicAlert("PendingConfirmation", awssdk.String("TEST")),
-				},
-				"aws_sns_topic_subscription.Incorrect": []alerter.Alert{
-					aws.NewWrongArnTopicAlert("Incorrect", awssdk.String("INCORRECT")),
-				},
+
+				alerter.On("SendAlert", "aws_sns_topic_subscription.PendingConfirmation", aws.NewWrongArnTopicAlert("PendingConfirmation", awssdk.String("TEST"))).Return()
+
+				alerter.On("SendAlert", "aws_sns_topic_subscription.Incorrect", aws.NewWrongArnTopicAlert("Incorrect", awssdk.String("INCORRECT"))).Return()
 			},
 			err: nil,
 		},
 		{
 			test:    "cannot list SNSTopic subscription",
 			dirName: "sns_topic_subscription_list",
-			mocks: func(client *repository.MockSNSRepository) {
-				client.On("ListAllSubscriptions").Return(nil, awserr.NewRequestFailure(nil, 403, ""))
-			},
-			alerts: map[string][]alerter.Alert{
-				resourceaws.AwsSnsTopicSubscriptionResourceType: {
-					alerts.NewRemoteAccessDeniedAlert("aws+tf", resourceaws.AwsSnsTopicSubscriptionResourceType, resourceaws.AwsSnsTopicSubscriptionResourceType, alerts.EnumerationPhase),
-				},
+			mocks: func(client *repository.MockSNSRepository, alerter *mocks.AlerterInterface) {
+				awsError := awserr.NewRequestFailure(awserr.New("AccessDeniedException", "", errors.New("")), 403, "")
+				client.On("ListAllSubscriptions").Return(nil, awsError)
+
+				alerter.On("SendAlert", resourceaws.AwsSnsTopicSubscriptionResourceType, alerts.NewRemoteAccessDeniedAlert(common.RemoteAWSTerraform, remoteerr.NewResourceListingErrorWithType(awsError, resourceaws.AwsSnsTopicSubscriptionResourceType, resourceaws.AwsSnsTopicSubscriptionResourceType), alerts.EnumerationPhase)).Return()
 			},
 			err: nil,
 		},
@@ -296,7 +296,7 @@ func TestSNSTopicSubscriptionScan(t *testing.T) {
 		t.Run(c.test, func(tt *testing.T) {
 			shouldUpdate := c.dirName == *goldenfile.Update
 
-			session := session.Must(session.NewSessionWithOptions(session.Options{
+			sess := session.Must(session.NewSessionWithOptions(session.Options{
 				SharedConfigState: session.SharedConfigEnable,
 			}))
 
@@ -305,9 +305,10 @@ func TestSNSTopicSubscriptionScan(t *testing.T) {
 			remoteLibrary := common.NewRemoteLibrary()
 
 			// Initialize mocks
-			alerter := alerter.NewAlerter()
+			alerter := &mocks.AlerterInterface{}
 			fakeRepo := &repository.MockSNSRepository{}
-			c.mocks(fakeRepo)
+			c.mocks(fakeRepo, alerter)
+
 			var repo repository.SNSRepository = fakeRepo
 			providerVersion := "3.19.0"
 			realProvider, err := terraform2.InitTestAwsProvider(providerLibrary, providerVersion)
@@ -324,11 +325,11 @@ func TestSNSTopicSubscriptionScan(t *testing.T) {
 					t.Fatal(err)
 				}
 				provider.ShouldUpdate()
-				repo = repository.NewSNSRepository(session, cache.New(0))
+				repo = repository.NewSNSRepository(sess, cache.New(0))
 			}
 
 			remoteLibrary.AddEnumerator(aws.NewSNSTopicSubscriptionEnumerator(repo, factory, alerter))
-			remoteLibrary.AddDetailsFetcher(resourceaws.AwsSnsTopicSubscriptionResourceType, aws.NewSNSTopicSubscriptionDetailsFetcher(provider, deserializer))
+			remoteLibrary.AddDetailsFetcher(resourceaws.AwsSnsTopicSubscriptionResourceType, common.NewGenericDetailsFetcher(resourceaws.AwsSnsTopicSubscriptionResourceType, provider, deserializer))
 
 			testFilter := &filter.MockFilter{}
 			testFilter.On("IsTypeIgnored", mock.Anything).Return(false)
@@ -339,8 +340,9 @@ func TestSNSTopicSubscriptionScan(t *testing.T) {
 			if err != nil {
 				return
 			}
-			assert.Equal(tt, c.alerts, alerter.Retrieve())
 			test.TestAgainstGoldenFile(got, resourceaws.AwsSnsTopicSubscriptionResourceType, c.dirName, provider, deserializer, shouldUpdate, tt)
+			alerter.AssertExpectations(tt)
+			fakeRepo.AssertExpectations(tt)
 		})
 	}
 }
